Stan Math Library: stan/math/fwd/core/operator_division.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

operator_division.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_CORE_OPERATOR_DIVISION_HPP
2 #define STAN_MATH_FWD_CORE_OPERATOR_DIVISION_HPP
3
4 #include <stan/math/fwd/core/fvar.hpp>
5
6
7 namespace stan {
8
9 namespace math {
10
11 template <typename T>
12 inline
13 fvar<T>
14 operator/(const fvar<T>& x1, const fvar<T>& x2) {
15 return fvar<T>(x1.val_ / x2.val_,
16 (x1.d_ * x2.val_ - x1.val_ * x2.d_) / (x2.val_ * x2.val_));
17 }
18
19 template <typename T>
20 inline
21 fvar<T>
22 operator/(const fvar<T>& x1, const double x2) {
23 return fvar<T>(x1.val_ / x2,
24 x1.d_ / x2);
25 }
26
27 template <typename T>
28 inline
29 fvar<T>
30 operator/(const double x1, const fvar<T>& x2) {
31 return fvar<T>(x1 / x2.val_,
32 - x1 * x2.d_ / (x2.val_ * x2.val_));
33 }
34 }
35 }
36 #endif
stan::math::operator/
fvar< T > operator/(const fvar< T > &x1, const fvar< T > &x2)
Definition: operator_division.hpp:14
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
fvar.hpp
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.